// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

type ClusterWorkflowTemplateExpansion interface{}

type CronWorkflowExpansion interface{}

type WorkflowExpansion interface{}

type WorkflowArtifactGCTaskExpansion interface{}

type WorkflowEventBindingExpansion interface{}

type WorkflowTaskResultExpansion interface{}

type WorkflowTaskSetExpansion interface{}

type WorkflowTemplateExpansion interface{}
