//go:build !pq
// +build !pq

package postgresql

// Copyright (c) 2012-present The upper.io/db authors. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import (
	"context"
	"database/sql"
	"time"

	_ "github.com/jackc/pgx/v5/stdlib"
	"github.com/upper/db/v4"
	"github.com/upper/db/v4/internal/sqladapter"
)

func (*database) OpenDSN(sess sqladapter.Session, dsn string) (*sql.DB, error) {
	connURL, err := ParseURL(dsn)
	if err != nil {
		return nil, err
	}

	if tz := connURL.Options["timezone"]; tz != "" {
		loc, err := time.LoadLocation(tz)
		if err != nil {
			return nil, err
		}

		ctx := context.WithValue(sess.Context(), db.ContextKey("timezone"), loc)
		sess.SetContext(ctx)
	}

	return sql.Open("pgx", dsn)
}
